Enum ros2_client::ServiceMapping
source · pub enum ServiceMapping {
Basic,
Enhanced,
Cyclone,
}Expand description
Selects how Service Requests and Responses are to be mapped to DDS.
There are different and incompatible ways to map Services onto DDS Topics. In order to interoperate with ROS 2, you have to select the same mapping it uses. The mapping used by ROS2 depends on the DDS implementation used and its configuration.
For details, see OMG Specification RPC over DDS Section “7.2.4 Basic and Enhanced Service Mapping for RPC over DDS”, which defines Service Mappings “Basic” and “Enhanced”.
ServiceMapping::Cyclone represents a third mapping used by RMW for CycloneDDS.
Variants
Basic
“Basic” service mapping from RPC over DDS specification.
- RTI Connext with
RMW_CONNEXT_REQUEST_REPLY_MAPPING=basic, but this is not tested, so may not work.
Enhanced
“Enhanced” service mapping from RPC over DDS specification.
- ROS2 Foxy with eProsima DDS,
- ROS2 Galactic with RTI Connext (rmw_connextdds, not rmw_connext_cpp) -
set environment variable
RMW_CONNEXT_REQUEST_REPLY_MAPPING=extendedbefore running ROS2 executable.
Cyclone
CycloneDDS-specific service mapping. Specification for this mapping is unknown, technical details are reverse-engineered from ROS2 sources.
- ROS2 Galactic with CycloneDDS - Seems to work on the same host only, not over actual network.