pub struct NewGoalHandle<G> { /* private fields */ }Expand description
NewGoalHandle is received from an action client. It can be either accepted
of rejected.
NewGoalHandle , AcceptedGoalHandle, and ExecutingGoalHandle are
different types because they support different operations.
AcceptedGoalHandle is the result of action server accepting a goal. The
action server can either start executing, or abort the goal, if it is no
longer possible.
ExecutingGoalHandle is the result of starting exeuction on a goal. It
supports:
publish_feedback- Notify action client that goal makes progresssend_result_response- Send the final result of the goal to the client (even if not successful)abort_executing_goal- Abort the goal, if it is no longer executable.
Implementations